========
Datasets
========

:mod:`aif360.datasets`
======================

.. automodule:: aif360.datasets
    :no-members:
    :no-inherited-members:

Base classes
------------

.. currentmodule:: aif360

.. autosummary::
   :toctree: generated/
   :template: class.rst

   datasets.Dataset
   datasets.StructuredDataset
   datasets.BinaryLabelDataset
   datasets.StandardDataset
   datasets.RegressionDataset

Common datasets
---------------

.. currentmodule:: aif360

.. autosummary::
   :toctree: generated/
   :template: class.rst

   datasets.AdultDataset
   datasets.BankDataset
   datasets.CompasDataset
   datasets.GermanDataset
   datasets.LawSchoolGPADataset
   datasets.MEPSDataset19
   datasets.MEPSDataset20
   datasets.MEPSDataset21
